@@ -23,9 +23,7 @@
 #'     x_labels = \(x) x,
 #'     y_title = "Level",
 #'   ) +
-#'   geom_line(
-#'     mapping = aes(y = level),
-#'   )
+#'   geom_line(mapping = aes(y = level))
 #'
 gg_ribbon <- function(
     data = NULL,
@@ -44,7 +42,6 @@ gg_ribbon <- function(
     yend = NULL,
     z = NULL,
     col = NULL,
-    # alpha = NULL,
     facet = NULL,
     facet2 = NULL,
     group = NULL,
@@ -79,8 +76,8 @@ gg_ribbon <- function(
     col_legend_rev = FALSE,
     col_limits = NULL,
     col_oob = scales::oob_keep,
-    col_pal = NULL,
-    col_pal_na = "darkgrey",
+    col_palette = NULL,
+    col_palette_na = NULL,
     col_rescale = scales::rescale(),
     col_steps = FALSE,
     col_title = NULL,
@@ -88,8 +85,6 @@ gg_ribbon <- function(
     facet_axes = NULL,
     facet_axis_labels = "margins",
     facet_labels = NULL,
-    facet_labels_position = "top",
-    facet_labels_switch = NULL,
     facet_layout = NULL,
     facet_ncol = NULL,
     facet_nrow = NULL,
@@ -118,7 +113,6 @@ gg_ribbon <- function(
     yend = {{ yend }},
     z = {{ z }},
     col = {{ col }},
-    # alpha = {{ alpha }},
     facet = {{ facet }},
     facet2 = {{ facet2 }},
     group = {{ group }},
@@ -153,8 +147,8 @@ gg_ribbon <- function(
     col_legend_rev = col_legend_rev,
     col_limits = col_limits,
     col_oob = col_oob,
-    col_pal = col_pal,
-    col_pal_na = col_pal_na,
+    col_palette = col_palette,
+    col_palette_na = col_palette_na,
     col_rescale = col_rescale,
     col_steps = col_steps,
     col_title = col_title,
@@ -162,8 +156,6 @@ gg_ribbon <- function(
     facet_axes = facet_axes,
     facet_axis_labels = facet_axis_labels,
     facet_labels = facet_labels,
-    facet_labels_position = facet_labels_position,
-    facet_labels_switch = facet_labels_switch,
     facet_layout = facet_layout,
     facet_ncol = facet_ncol,
     facet_nrow = facet_nrow,
