@@ -131,15 +131,12 @@ test_name <- "6"
 
 test_that(test_name, {
   p <- penguins |>
-    mutate(hack = "") |>
     gg_boxplot(
       x = species,
       y = flipper_length_mm,
-      col = hack,
       colour = "black", #or fill = #D3D3D3",
       width = 0.5,
       alpha = 0.9,
-      mode = light_mode_n(),
     )
 
   vdiffr::expect_doppelganger(test_name, p)
@@ -325,10 +322,8 @@ test_that(test_name, {
       y = unemploy,
       subtitle = "\nNo x_limits set",
       se = TRUE) +
-    geom_vline(xintercept = c(lubridate::ymd("1985-01-01", "1995-01-01")),
-               col = blue,
-               linetype = 3) +
-    geom_point(col = blue, alpha = 0.3)
+    geom_vline(xintercept = c(lubridate::ymd("1985-01-01", "1995-01-01"))) +
+    geom_point(alpha = 0.3)
 
   p2 <- economics |>
     filter(between(date, lubridate::ymd("1985-01-01"), lubridate::ymd("1995-01-01"))) |>
@@ -338,7 +333,7 @@ test_that(test_name, {
       se = TRUE,
       x_labels = \(x) stringr::str_sub(x, 3, 4),
       subtitle = "\nx data filtered") +
-    geom_point(col = blue, alpha = 0.3)
+    geom_point(alpha = 0.3)
 
   p <- p1 + p2
 
@@ -360,7 +355,7 @@ test_that(test_name, {
       x_labels = \(x) stringr::str_sub(x, 3, 4),
       subtitle = "\nx_limits set",
     ) +
-    geom_point(col = blue, alpha = 0.3)
+    geom_point(alpha = 0.3)
 
   vdiffr::expect_doppelganger(test_name, p)
 })
@@ -380,7 +375,7 @@ test_that(test_name, {
       x_labels = \(x) stringr::str_sub(x, 3, 4),
       coord = coord_cartesian(clip = "on"),
       subtitle = "\nx_limits set & cartesian space clipped") +
-    geom_point(col = blue, alpha = 0.3)
+    geom_point(alpha = 0.3)
 
   p5 <- economics |>
     gg_smooth(
@@ -391,7 +386,7 @@ test_that(test_name, {
       x_labels = \(x) stringr::str_sub(x, 3, 4),
       x_oob = scales::oob_censor,
       subtitle = "\nx_limits set & x_oob censored") +
-    geom_point(col = blue, alpha = 0.3)
+    geom_point(alpha = 0.3)
 
 
   p <- p4 + p5
@@ -412,7 +407,7 @@ test_that(test_name, {
       x = displ,
       y = hwy,
       col = centred,
-      col_pal = c(teal, "#E8EFF2", orange),
+      col_palette = c(teal, "#E8EFF2", orange),
       col_breaks = scales::breaks_width(5),
       col_rescale = scales::rescale(c(min(.$centred), 0, max(.$centred)))
     )
@@ -433,7 +428,7 @@ test_that(test_name, {
       x = displ,
       y = hwy,
       col = centred,
-      col_pal = c(teal, "#E8EFF2", orange),
+      col_palette = c(teal, "#E8EFF2", orange),
       col_limits = max(abs(.$centred)) * c(-1, 1),
       col_breaks = scales::breaks_width(5)
     )
@@ -487,4 +482,4 @@ test_that(test_name, {
   vdiffr::expect_doppelganger(test_name, p)
 })
 
-
+set_blanket()
